pub struct UnsignedBody {
pub abi_version: AbiVersion,
pub payload: Cell,
pub hash: HashBytes,
pub expire_at: u32,
}Expand description
Unsigned external message payload.
Fields
abi_version: AbiVersionABI version used during encoding.
payload: CellUnsigned payload.
hash: HashBytesA hash to sign.
expire_at: u32Message expiration timestamp (in seconds).
Implementations
Sourceimpl UnsignedBody
impl UnsignedBody
Sourcepub fn with_dst(self, dst: StdAddr) -> UnsignedExternalMessage
pub fn with_dst(self, dst: StdAddr) -> UnsignedExternalMessage
Extends message with the specified destination address and returns an unsigned external message.
Sourcepub fn sign(self, key: &SigningKey, context: SignatureContext) -> Result<Cell>
pub fn sign(self, key: &SigningKey, context: SignatureContext) -> Result<Cell>
Signs the payload and returns a body cell with filled signature.
Sourcepub fn sign_with<F>(self, f: F) -> Result<Cell>
pub fn sign_with<F>(self, f: F) -> Result<Cell>
Signs the payload with the specified closure and returns a body cell with filled signature.
Sourcepub fn with_signature(self, signature: &Signature) -> Result<Cell>
pub fn with_signature(self, signature: &Signature) -> Result<Cell>
Returns a body cell with filled signature.
Sourcepub fn with_fake_signature(self) -> Result<Cell>
pub fn with_fake_signature(self) -> Result<Cell>
Returns a body cell with signature filled with zero bytes.
Sourcepub fn without_signature(self) -> Result<Cell>
pub fn without_signature(self) -> Result<Cell>
Returns a body cell with empty signature.