UnsignedExternalMessage

Struct UnsignedExternalMessage 

pub struct UnsignedExternalMessage {
    pub dst: StdAddr,
    pub body: UnsignedBody,
    pub init: Option<StateInit>,
}
Unsigned external message.

Fields

dst: StdAddr

Destination contract address.

body: UnsignedBody

Unsigned payload.

init: Option<StateInit>

Optional initial contract state.

Implementations

Source

impl UnsignedExternalMessage

pub fn set_state_init(&mut self, init: Option<StateInit>)

Updates the state init of the external message to the specified one.

pub fn with_state_init(self, init: StateInit) -> Self

Returns an external message with the specified state init.

pub fn with_state_init_opt(self, init: Option<StateInit>) -> Self

Returns an external message with the specified state init.

pub fn expire_at(&self) -> u32

Returns the expiration timestamp of this message.

pub fn sign( self, key: &SigningKey, context: SignatureContext, ) -> Result<OwnedMessage>

Signs the payload and returns an external message with filled signature.

pub fn sign_with<F>(self, f: F) -> Result<OwnedMessage>
where for<'a> F: FnOnce(&'a HashBytes) -> Signature,

Signs the payload with the specified closure and returns an external message with filled signature.

pub fn with_signature(self, signature: &Signature) -> Result<OwnedMessage>

Returns an external message with filled signature.

pub fn with_fake_signature(self) -> Result<OwnedMessage>

Returns an external message with signature filled with zero bytes.

pub fn without_signature(self) -> Result<OwnedMessage>

Returns an external message with empty signature.

pub fn fill_signature( &self, signature: Option<&[u8; 64]>, ) -> Result<OwnedMessage>

Returns an external message with filled signature.