CellType

Enum CellType 

pub enum CellType {
    Ordinary,
    PrunedBranch,
    LibraryReference,
    MerkleProof,
    MerkleUpdate,
}
Well-formed cell type.

Variants



Ordinary

Cell of this type just stores data and references.



PrunedBranch

Exotic cell which was pruned from the original tree of cells when a Merkle proof has been created.



LibraryReference

Exotic cell with a reference to the cell with a library.



MerkleProof

Exotic cell with one hash and one reference.



MerkleUpdate

Exotic cell with two hashes and two references.

Implementations

Source

impl CellType

pub const fn is_merkle(self) -> bool

Returns whether this cell type is Merkle proof or Merkle update.

pub const fn is_exotic(self) -> bool

Returns whether the cell is not ordinary.

pub const fn is_pruned_branch(self) -> bool

Returns whether the cell is a pruned branch.

pub const fn is_library(self) -> bool

Returns whether this cell is a library cell.

pub const fn to_byte(self) -> u8

Encodes cell type as byte.

pub const fn from_byte(byte: u8) -> Option<Self>

Decodes any cell type from byte.

pub const fn from_byte_exotic(byte: u8) -> Option<Self>

Decodes exotic cell type from byte.