CellSliceRange

Struct CellSliceRange 

pub struct CellSliceRange { /* private fields */ }
Indices of the slice data and refs windows.

Implementations

Source

impl CellSliceRange

pub const fn empty() -> Self

Returns an empty slice range.

pub fn full<T>(cell: &T) -> Self
where T: AsRef<DynCell> + ?Sized,

Returns a full range for the specified cell.

pub fn apply<T>(self, cell: &T) -> Result<CellSlice<'_>, Error>
where T: AsRef<DynCell> + ?Sized,

Constructs a new cell slice from the specified cell using the current range. Returns an error if the cell is pruned.

NOTE: the resulting range will be truncated to cell bounds.

pub fn apply_allow_exotic<T>(self, cell: &T) -> CellSlice<'_>
where T: AsRef<DynCell> + ?Sized,

Constructs a new cell slice from the specified cell using the current range.

NOTE: the resulting range will be truncated to cell bounds.

Safety

The following must be true:

  • cell is not pruned
  • range is in cell bounds
pub const fn size(&self) -> Size

Returns the number of remaining bits and refs in the slice.

pub const fn size_bits(&self) -> u16

Returns the number of remaining bits of data in the slice.

pub const fn size_refs(&self) -> u8

Returns the number of remaining references in the slice.

pub const fn is_empty(&self) -> bool

Returns whether there are no data bits and refs left.

pub const fn is_data_empty(&self) -> bool

Returns whether there are no bits of data left.

pub const fn is_refs_empty(&self) -> bool

Returns whether there are no references left.

pub const fn offset(&self) -> Size

Returns the start of data and reference windows.

pub const fn offset_bits(&self) -> u16

Returns the start of the data window.

pub const fn offset_refs(&self) -> u8

Returns the start of the references window.

pub const fn has_remaining(&self, bits: u16, refs: u8) -> bool

Returns true if the slice contains at least bits and refs.

pub fn skip_first(&mut self, bits: u16, refs: u8) -> Result<(), Error>

Tries to advance the start of data and refs windows.

pub fn only_first(&mut self, bits: u16, refs: u8) -> Result<(), Error>

Leaves only the first bits and refs in the slice.

pub fn skip_last(&mut self, bits: u16, refs: u8) -> Result<(), Error>

Removes the last bits and refs from the slice.

pub fn only_last(&mut self, bits: u16, refs: u8) -> Result<(), Error>

Leaves only the last bits and refs in the slice.

pub fn split_prefix(&mut self, bits: u16, refs: u8) -> Result<Self, Error>

Returns the first bits and refs of the slice and advances the start of data and refs windows.

pub fn split_suffix(&mut self, bits: u16, refs: u8) -> Result<Self, Error>

Returns the last bits and refs of the slice and shrinks the data and refs windows.

pub fn get_prefix(&self, bits: u16, refs: u8) -> Self

Returns a slice range starting at the same bits and refs offsets, and containing no more than bits of data and refs of children.

pub fn is_full<T>(&self, cell: &T) -> bool
where T: AsRef<DynCell> + ?Sized,

Returns whether this range has the same size as the cell.