LevelMask

Struct LevelMask 

pub struct LevelMask(/* private fields */);
de Brujn level presence bitset.

Implementations

Source

impl LevelMask

pub const EMPTY: Self

Empty bitset.

pub const MAX_LEVEL: u8 = 3

Max de Brujn level.

pub const fn new(mask: u8) -> Self

Constructs a new level mask, truncating extra bits.

pub const fn is_empty(self) -> bool

Returns true if there are no levels in mask.

pub const unsafe fn new_unchecked(mask: u8) -> Self

Constructs a new level mask from the provided byte as is.

Safety

The following must be true:

  • Mask must be in range 0b000..=0b111.
pub const fn from_level(level: u8) -> Self

Creates a sufficient mask for the specified level.

NOTE: levels > 3 has no effect (mask will always be 0b111).

pub const fn level(self) -> u8

Counts presented higher hashes.

pub const fn hash_index(self, level: u8) -> u8

Computes hash index for the specified level.

pub const fn contains(self, level: u8) -> bool

Returns whether the specified level is included into the mask.

pub const fn virtualize(self, offset: u8) -> Self

Creates a new mask, shifted by the offset.

pub const fn to_byte(self) -> u8

Encodes level mask as byte.