pub struct ComputeGasParams<'a> {
pub account_balance: &'a Tokens,
pub message_balance: &'a Tokens,
pub is_special: bool,
pub is_tx_ordinary: bool,
pub is_in_msg_external: bool,
}Expand description
An input of GasLimitsPrices::compute_gas_params.
Fields
account_balance: &'a TokensAccount balance in native currency.
message_balance: &'a TokensMessage balance in native currency.
is_special: boolWhether the account is present in a fundamental addresses list.
is_tx_ordinary: boolWhether the gas is computed for an ordinary transaction.
is_in_msg_external: boolWhether the received message is external.