pub struct ElectionTimings {
pub validators_elected_for: u32,
pub elections_start_before: u32,
pub elections_end_before: u32,
pub stake_held_for: u32,
}Expand description
Validators election timings.
Fields
validators_elected_for: u32Validation round length in seconds.
elections_start_before: u32Duration in seconds until the end of the validation round when the election starts.
elections_end_before: u32Duration in seconds until the end of the validation round when the election ends.
stake_held_for: u32How long validator stake will be frozen after the validation round end.