GlobalCapability

Enum GlobalCapability 

#[repr(u64)]
pub enum GlobalCapability {
Show 35 variants CapIhrEnabled = 1, CapCreateStatsEnabled = 2, CapBounceMsgBody = 4, CapReportVersion = 8, CapSplitMergeTransactions = 16, CapShortDequeue = 32, CapMbppEnabled = 64, CapFastStorageStat = 128, CapInitCodeHash = 256, CapOffHypercube = 512, CapMyCode = 1_024, CapSetLibCode = 2_048, CapFixTupleIndexBug = 4_096, CapRemp = 8_192, CapDelections = 16_384, CapFullBodyInBounced = 65_536, CapStorageFeeToTvm = 131_072, CapCopyleft = 262_144, CapIndexAccounts = 524_288, CapDiff = 1_048_576, CapsTvmBugfixes2022 = 2_097_152, CapWorkchains = 4_194_304, CapStcontNewFormat = 8_388_608, CapFastStorageStatBugfix = 16_777_216, CapResolveMerkleCell = 33_554_432, CapSignatureWithId = 67_108_864, CapBounceAfterFailedAction = 134_217_728, CapGroth16 = 268_435_456, CapFeeInGasUnits = 536_870_912, CapBigCells = 1_073_741_824, CapSuspendedList = 2_147_483_648, CapFastFinality = 4_294_967_296, CapSuspendByMarks = 8_589_934_592, CapOmitMasterBlockHistory = 17_179_869_184, CapSignatureDomain = 34_359_738_368,
}
Node software capabilities.

Variants



CapIhrEnabled = 1

Instant Hypercube Routing.

Mask: 0x0000001.



CapCreateStatsEnabled = 2

Tracking of block collation stats.

Mask: 0x0000002.



CapBounceMsgBody = 4

Body (at most 256 bits) in bounced messages.

Mask: 0x0000004.



CapReportVersion = 8

Supported software version and capabilities as field in BlockInfo.

Mask: 0x0000008.



CapSplitMergeTransactions = 16

Special transactions on split or merge.

Mask: 0x0000010.



CapShortDequeue = 32

Short output messages queue.

Mask: 0x0000020.



CapMbppEnabled = 64

unknown (possibly just a stub).

Mask: 0x0000040.



CapFastStorageStat = 128

Precompute storage stats for cells and use this info for storage phase. NOTE: changes behavior for storage phase, computing stats for non-unique cells.

Mask: 0x0000080



CapInitCodeHash = 256

Store init code hash in account state.

Mask: 0x0000100.



CapOffHypercube = 512

Disable hypercube for message routing.

Mask: 0x0000200.



CapMyCode = 1_024

MYCODE TVM opcode.

Mask: 0x0000400.



CapSetLibCode = 2_048

CHANGELIB and SETLIBCODE TVM opcodes.

Mask: 0x0000800.



CapFixTupleIndexBug = 4_096

Fix in SETINDEX* TVM opcodes.

Mask: 0x0001000.



CapRemp = 8_192

Reliable External Messaging Protocol.

Mask: 0x0002000.



CapDelections = 16_384

Support for decentralized elections.

Mask: 0x0004000.



CapFullBodyInBounced = 65_536

Full message body in bounced messages (in the first child cell).

Mask: 0x0010000.



CapStorageFeeToTvm = 131_072

STORAGEFEE TVM opcode.

Mask: 0x0020000.



CapCopyleft = 262_144

Support for copyleft messages.

Mask: 0x0040000.



CapIndexAccounts = 524_288

FIND_BY_* TVM opcodes.

Mask: 0x0080000.



CapDiff = 1_048_576

DIFF*, ZIP, UNZIP TVM opcodes.

Mask: 0x0100000.



CapsTvmBugfixes2022 = 2_097_152

Cumulative patches to TVM and cells (popsave, exception handler, loops).

Mask: 0x0200000.



CapWorkchains = 4_194_304

Support for message queues between workchains.

Mask: 0x0400000.



CapStcontNewFormat = 8_388_608

New continuation serialization format.

Mask: 0x0800000.



CapFastStorageStatBugfix = 16_777_216

Use fast stats for *DATASIZE* TVM opcodes.

Mask: 0x1000000.



CapResolveMerkleCell = 33_554_432

Add support for transparent loading of merkle cells.

Mask: 0x2000000.



CapSignatureWithId = 67_108_864

Prepend signature with global_id for TVM.

Mask: 0x4000000.



CapBounceAfterFailedAction = 134_217_728

Execute bounce phase even after failed action phase.

Mask: 0x8000000.



CapGroth16 = 268_435_456

Groth16 support in TVM.

Mask: 0x10000000



CapFeeInGasUnits = 536_870_912

Makes all fees in config in gas units.

Mask: 0x20000000



CapBigCells = 1_073_741_824

Big cells support.

Mask: 0x40000000



CapSuspendedList = 2_147_483_648

Suspend addresses using a config param.

Mask: 0x80000000



CapFastFinality = 4_294_967_296

Adds intershard communication between master blocks.

Mask: 0x100000000



CapSuspendByMarks = 8_589_934_592

Allows to suspend accounts by special extra currencies.

Mask: 0x200000000



CapOmitMasterBlockHistory = 17_179_869_184

Omits master block history to save storage space.

Mask: 0x400000000



CapSignatureDomain = 34_359_738_368

Apply signature domain to verified data.

It is a newer version of GlobalCapability::CapSignatureWithId and has a higher priority if both are enabled at the same time.

Mask: 0x800000000