NewBounceBody

Struct NewBounceBody 

pub struct NewBounceBody {
    pub original_body: Cell,
    pub original_info: Lazy<NewBounceOriginalInfo>,
    pub bounced_by_phase: u8,
    pub exit_code: i32,
    pub compute_phase: Option<NewBounceComputePhaseInfo>,
}
New bounce message body.

Fields

original_body: Cell

Cell that contains the body of the original message. If MessageExtraFlags::is_full_body_in_bounced returns true, then the whole body is returned, otherwise it is only the root without refs.

original_info: Lazy<NewBounceOriginalInfo>

Original message info

bounced_by_phase: u8

Id of a failed phase.

  • 0 - compute phase was skipped. exit_code denotes the skip reason:
    • exit_code = -1 - no state (account is uninit or frozen, and no state init is present in the message).
    • exit_code = -2 - bad state (account is uninit or frozen, and state init in the message has the wrong hash).
    • exit_code = -3 - no gas.
    • exit_code = -4 - account is suspended.
  • 1 - compute phase failed. exit_code is the value from the compute phase.
  • 2 - action phase failed. exit_code is the value from the action phase.
exit_code: i32

Exit code (or a skip reason if compute phase was skipped).

compute_phase: Option<NewBounceComputePhaseInfo>

Compute phase info

Implementations

Source

impl NewBounceBody

pub const COMPUTE_PHASE_SKIPPED: u8 = 0

State of NewBounceBody::bounced_by_phase when compute phase was skipped.

pub const COMPUTE_PHASE_FAILED: u8 = 1

State of NewBounceBody::bounced_by_phase when compute phase failed.

pub const ACTION_PHASE_FAILED: u8 = 2

State of NewBounceBody::bounced_by_phase when action phase failed.

pub const EXIT_CODE_NO_STATE: i32 = -1

State of NewBounceBody::exit_code when there was no state.

pub const EXIT_CODE_BAD_STATE: i32 = -2

State of NewBounceBody::exit_code when there was an invalid state.

pub const EXIT_CODE_NO_GAS: i32 = -3

State of NewBounceBody::exit_code when there was not enough gas.

pub const EXIT_CODE_SUSPENDED: i32 = -4

State of NewBounceBody::exit_code when the account was suspended.

pub const fn bounce_reason(&self) -> Option<BounceReason>

Get a structured bounce reason info (if well-formed).