GenesisInfo

Struct GenesisInfo 

pub struct GenesisInfo {
    pub start_round: u32,
    pub genesis_millis: u64,
}
Brief genesis info.

genesis_info#_
    start_round:uint32
    genesis_millis:uint64
    = GenesisInfo;

Fields

start_round: u32

Unaligned genesis round that corresponds to the last (maybe partially) processed anchor from the last master chain block signed by majority. Aligned (a bit increased or left unchanged) genesis round affects the overlay id.

genesis_millis: u64

Timestamp in milliseconds to include into mempool genesis point. Newly produced points are required to have greater value. Unchanged value affects the overlay id.

Implementations

Source

impl GenesisInfo

pub fn overrides(&self, other: &Self) -> bool

If genesis overrides the other, then it will be used to start a blank new mempool session