pub enum ContractInitData {
Dict(HashMap<Arc<str>, (u64, NamedAbiType)>),
PlainFields(HashSet<Arc<str>>),
}Expand description
Contract initialization data representation.
Variants
Dict(HashMap<Arc<str>, (u64, NamedAbiType)>)
Dictionary-based init data for ABI versions < 2.4.
Maps field names to tuples of (key, named type), where the key is used for dictionary lookups in the contract storage.
PlainFields(HashSet<Arc<str>>)
Plain fields init data for ABI versions >= 2.4.
Contains a set of field names that represent the initialization data. These fields are stored sequentially in the contract data cell.