pub struct SerializeAbiValueParams {
pub big_numbers_as_hex: bool,
pub small_numbers_as_is: bool,
}Expand description
Serialization params for AbiValue.
Fields
big_numbers_as_hex: boolInteger types with bit width greater than 128
will be serialized as hex (with 0x prefix).
Default: false.
small_numbers_as_is: boolInteger values with bit len not greater than 53 will be serialized as is (e.g. as JSON numbers).
Default: false.
Implementations
Sourceimpl SerializeAbiValueParams
impl SerializeAbiValueParams
Sourcepub const NUMBERS_AS_HEX_THRESHOLD: u16 = 128
pub const NUMBERS_AS_HEX_THRESHOLD: u16 = 128
Number of bits after which the number will be serialized as hex.
Sourcepub const NUMBERS_AS_IS_THRESHOLD: u16 = 53
pub const NUMBERS_AS_IS_THRESHOLD: u16 = 53
Number of bits before which the number will be serialized as is (e.g. as JSON number).
See [https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/MAX_SAFE_INTEGER].